CubicEdge class

Cubic bezier curve in path. Note that offers a novel API that is more human friendly: describe curve features in way that is invariant to size, rather than the standard control points (which are implicitly related to start and end points).

Inheritance

Constructors

CubicEdge({required Point<double> from, required Point<double> to, required bool positive, required double curveSize, required double curveAngle, required double bulbousness, required double twist})

Properties

bulbousness ↔ double
getter/setter pair
curveAngle ↔ double
getter/setter pair
curveSize ↔ double
getter/setter pair
end → Point<double>
End of edge
no setteroverride
from ↔ Point<double>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
positive ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → Point<double>
Start of edge
no setteroverride
to ↔ Point<double>
getter/setter pair
twist ↔ double
getter/setter pair

Methods

addToPath(Path path) → void
Add to a (standard) Path; for drawing
override
copy() → PathEdge
Make a copy, want to ensure immutability in some places
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transformed(Point<double> transform(Point<double>)) → PathEdge
Transform an edge with a function (on Point
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited