LineEdge class

A line part of a path

Inheritance

Constructors

LineEdge(Point<double> from, Point<double> to)

Properties

end → Point<double>
End of edge
no setteroverride
from ↔ Point<double>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → Point<double>
Start of edge
no setteroverride
to ↔ Point<double>
getter/setter pair

Methods

addToPath(Path path) → void
Add to a (standard) Path; for drawing
override
copy() → PathEdge
Make a copy, want to ensure immutability in some places
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transformed(Point<double> transform(Point<double>)) → PathEdge
Transform an edge with a function (on Point
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited