PathEdge class abstract

Have lines or bezier curves, hence this parent class

Implementers

Constructors

PathEdge()

Properties

end → Point<double>
End of edge
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → Point<double>
Start of edge
no setter

Methods

addToPath(Path path) → void
Add to a (standard) Path; for drawing
copy() → PathEdge
Make a copy, want to ensure immutability in some places
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transformed(Point<double> transform(Point<double>)) → PathEdge
Transform an edge with a function (on Point

Operators

operator ==(Object other) → bool
The equality operator.
inherited