Area class

A simple class for (rectangular) parts of a canvas. Makes it easy to iterate over a canvas.

Constructors

Area(Point<double> origin, Size delta, Point<double> center, int index)

Properties

center ↔ Point<double>
getter/setter pair
delta ↔ Size
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
getter/setter pair
origin ↔ Point<double>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited